@@ -1,4 +1,4 @@
-from com import Component, Viewer, msgs
+from com import Component, Viewer, Widget, msgs
 import components
 from utils import logging
 
@@ -6,8 +6,6 @@ from mediabox.MainWindow import MainWindow
 from mediabox.RootPane import RootPane
 from mediabox.TitlePanel import TitlePanel
 from mediabox.ControlPanel import ControlPanel
-from mediabox.TabPanel import TabPanel
-from mediabox.WindowControls import WindowControls
 from mediabox.ViewerState import ViewerState
 from ui.Image import Image
 from ui.Pixmap import Pixmap
@@ -39,8 +37,6 @@ class AppWindow(Component, RootPane):
         self.__viewers = []
         self.__current_viewer = None
         self.__current_device_id = ""
-        self.__current_collection = []
-        self.__current_mediaroots = []
         self.__view_mode = viewmodes.TITLE_ONLY
         self.__battery_remaining = 100.0
         
@@ -70,7 +66,7 @@ class AppWindow(Component, RootPane):
         try:
             theme.set_theme(config.theme())
         except:
-            # theme could not be loaded
+            # theme could not be loaded; using default theme
             pass
 
 
@@ -91,13 +87,12 @@ class AppWindow(Component, RootPane):
 
         # screen pixmap
         screen = Pixmap(self.__window.window)
-
         
         Component.__init__(self)
-        RootPane.set_event_sensor(self.__window)
         RootPane.__init__(self)
+        self.set_window(self.__window)
         self.set_size(w, h)
-        self.set_screen(screen)      
+        self.set_screen(screen)
 
         # image strip       
         self.__strip = ImageStrip(5)
@@ -126,23 +121,8 @@ class AppWindow(Component, RootPane):
         self.__ctrl_panel = ControlPanel()
         self.__ctrl_panel.set_visible(False)
 
-        # tab panel and window controls
-        self.__tab_panel = TabPanel()
-        self.__tab_panel.set_visible(False)
-        self.__tab_panel.add_observer(self.__on_observe_tabs)
-        self.add(self.__tab_panel)
-        
-        self.__window_ctrls = WindowControls()
-        self.__window_ctrls.set_visible(False)
-        self.__window_ctrls.add_observer(self.__on_observe_window_ctrls)
-
-        self.__touch_back_area = EventBox()
-        self.__touch_back_area.connect_button_pressed(
-                                          lambda x,y:self.__hide_tabs())
-        self.__touch_back_area.set_visible(False)
-        self.add(self.__touch_back_area)
-
         self.__startup()
+
         
        
     def __startup(self):
@@ -157,8 +137,6 @@ class AppWindow(Component, RootPane):
                                         "",
                                         theme.mb_viewer_audio]),
                    (self.__register_viewers, []),
-                   (self.add, [self.__tab_panel]),
-                   (self.add, [self.__window_ctrls]),
                    (self.__add_panels, []),
                    (self.__scan_at_startup, []),
                    (self.hide_overlay, []),
@@ -206,6 +184,7 @@ class AppWindow(Component, RootPane):
         current_viewer = config.current_viewer()
         current_device_id = config.current_device()
         self.__select_viewer_by_name(current_viewer)
+        self.emit_event(msgs.UI_ACT_SELECT_VIEWER, current_viewer)
         self.emit_event(msgs.UI_ACT_SELECT_DEVICE, current_device_id)
 
 
@@ -218,7 +197,6 @@ class AppWindow(Component, RootPane):
 
         for viewer in self.__viewers:
             logging.info("registering viewer [%s]", viewer)
-            self.__tab_panel.add_viewer(viewer)
             self.add(viewer)
             viewer.set_visible(False)        
 
@@ -275,6 +253,7 @@ class AppWindow(Component, RootPane):
         """
 
         if (not self.__is_initialized): return
+        if (view_mode == self.__view_mode): return
 
         w, h = self.get_size()
 
@@ -401,79 +380,10 @@ class AppWindow(Component, RootPane):
         Reacts on pressing the menu button.
         """
         
-        self.__show_tabs()
+        #self.__show_tabs()
+        self.emit_message(msgs.INPUT_EV_MENU)
 
 
-    def __show_tabs(self):
-          
-        w, h = self.get_size()
-
-        self.set_enabled(False)
-        self.set_frozen(True)
-        
-        self.__tab_panel.render()
-
-        self.__tab_panel.set_enabled(True)
-        self.__tab_panel.set_frozen(False)        
-        self.__tab_panel.set_visible(True)
-        
-        self.__tab_panel.fx_raise()
-        
-        cw, ch = self.__window_ctrls.get_size()
-        tw, th = self.__tab_panel.get_size()
-        self.__tab_panel.set_pos(0, h - th)
-
-        self.__window_ctrls.set_frozen(False)
-        self.__window_ctrls.set_enabled(True)
-        self.__window_ctrls.set_geometry(w - cw, 0, cw, ch)        
-        self.__window_ctrls.set_visible(True)
-        self.__window_ctrls.fx_slide_in()
-        
-        self.__touch_back_area.set_visible(True)
-        self.__touch_back_area.set_enabled(True)
-        self.__touch_back_area.set_geometry(0, 0, w - cw, h - th)
-        
-        self.emit_event(msgs.INPUT_EV_CONTEXT_MENU)
-        self.emit_event(msgs.UI_EV_VIEWER_CHANGED, -1)
-
-
-    def __hide_tabs(self):
-    
-        self.__window_ctrls.set_visible(False)
-        self.__window_ctrls.fx_slide_out()
-        self.__tab_panel.set_visible(False)
-        self.__touch_back_area.set_visible(False)
-
-        self.__tab_panel.fx_lower()
-        self.set_enabled(True)
-        self.set_frozen(False)
-        self.render_buffered()
-        
-        self.emit_event(msgs.INPUT_ACT_REPORT_CONTEXT)
-        try:
-            viewer_idx = self.__viewers.index(self.__current_viewer)
-        except:
-            viewer_idx = 0
-        self.emit_event(msgs.UI_EV_VIEWER_CHANGED, viewer_idx)
-
-
-    def __select_tab(self, idx):
-
-        if (self.__viewers[idx] != self.__current_viewer):
-            self.__window_ctrls.set_visible(False)
-            self.__window_ctrls.fx_slide_out()
-            self.__tab_panel.set_visible(False)
-            self.__touch_back_area.set_visible(False)
-
-            self.set_enabled(True)
-            self.set_frozen(False)
-            self.__select_viewer(idx)
-            
-        else:
-            self.__hide_tabs()
-
-        
-
 
     def __scan_media(self, force_rebuild):
         """
@@ -482,32 +392,18 @@ class AppWindow(Component, RootPane):
         @param force_scan: scan even if mediaroots and types haven't changed
         """
         
-        #if (force_scan):
-        #    self.__current_mediaroots = []
-
         mediaroots = config.mediaroot()        
     
-        #if (`mediaroots` == `self.__current_mediaroots`):
-        #    return
-        #else:
-        #    self.__current_mediaroots = mediaroots
-
         if (not mediaroots):
-            dialogs.warning("No media library specified!",
-                            "Please specify the contents of your\n"
-                            "media library in the folder viewer.")
+        #    dialogs.warning("No media library specified!",
+        #                    "Please specify the contents of your\n"
+        #                    "media library in the folder viewer.")
             return
         #end if
 
 
-        self.show_overlay("Scanning Media", "", theme.mb_viewer_audio)
-        #self.call_service(msgs.NOTIFY_SVC_SHOW_INFO, "Scanning media")
+        #self.show_overlay("Scanning Media", "", theme.mb_viewer_audio)
 
-        #paths = []
-        #for path, mtypes in mediaroots:
-        #    f = self.call_service(msgs.CORE_SVC_GET_FILE, path)
-        #    if (f): paths.append((f, mtypes))
-        #end for
         self.emit_event(msgs.MEDIASCANNER_ACT_SCAN, mediaroots, force_rebuild)
         
 
@@ -518,7 +414,7 @@ class AppWindow(Component, RootPane):
 
 
         import gc; gc.collect()
-        self.hide_overlay()
+        #self.hide_overlay()
 
                         
     def __on_close_window(self, src, ev):
@@ -535,7 +431,6 @@ class AppWindow(Component, RootPane):
             screen = Pixmap(self.__window.window)
             self.set_screen(screen)
             self.set_size(w, h)
-            self.__tab_panel.set_size(w, 0)
             self.render_buffered()
 
     def __on_expose(self, src, ev):
@@ -546,18 +441,7 @@ class AppWindow(Component, RootPane):
 
 
     def __on_key(self, src, ev):
-
-        # show memory consumption      
-        import os
-        pid = os.getpid()
-        size = int(open("/proc/%d/status" % pid, "r").read().splitlines()[15].split()[1])
-        size /= 1024.0
-        logging.debug("current Resident Set Size: %0.02f MB", size)
-
-
-        #if (not self.is_enabled()): return
-        #if (self.have_animation_lock()): return
-    
+   
         keyval = ev.keyval
         key = gtk.gdk.keyval_name(keyval)
 
@@ -566,40 +450,49 @@ class AppWindow(Component, RootPane):
         if (key == "space"): key = " "
         
         if (key == "Escape"):
-            pass #self.emit_event(msgs.HWKEY_EV_ESCAPE)
+            print "Escape"
+            self.emit_event(msgs.HWKEY_EV_ESCAPE)
         
         elif (key == "Return"):
             self.emit_event(msgs.HWKEY_EV_ENTER)
-                
+
+        elif (key == "F1"):
+            self.emit_event(msgs.HWKEY_EV_F1)
+        elif (key == "F2"):
+            self.emit_event(msgs.HWKEY_EV_F2)
+        elif (key == "F3"):
+            self.emit_event(msgs.HWKEY_EV_F3)
+        elif (key == "F4"):
+            self.emit_event(msgs.HWKEY_EV_F4)
+        elif (key == "F5"):
+            self.emit_event(msgs.HWKEY_EV_F5)
         elif (key == "F6"):
-            self.emit_event(msgs.HWKEY_EV_FULLSCREEN)
+            self.emit_event(msgs.HWKEY_EV_F6)
+            self.emit_event(msgs.HWKEY_EV_FULLSCREEN)  # deprecated
         elif (key == "F7"):
-            self.emit_event(msgs.HWKEY_EV_INCREMENT)
+            self.emit_event(msgs.HWKEY_EV_F7)
+            self.emit_event(msgs.HWKEY_EV_INCREMENT)  # deprecated
         elif (key == "F8"):
-            self.emit_event(msgs.HWKEY_EV_DECREMENT)
+            self.emit_event(msgs.HWKEY_EV_F8)
+            self.emit_event(msgs.HWKEY_EV_DECREMENT)  # deprecated
+        elif (key == "F9"):
+            self.emit_event(msgs.HWKEY_EV_F9)
+        elif (key == "F10"):
+            self.emit_event(msgs.HWKEY_EV_F10)
+        elif (key == "F11"):
+            self.emit_event(msgs.HWKEY_EV_F11)
         elif (key == "F12"):
-            self.emit_event(msgs.HWKEY_EV_EJECT)
+            self.emit_event(msgs.HWKEY_EV_F12)
+            self.emit_event(msgs.HWKEY_EV_EJECT)  # deprecated
             
         elif (key == "Up"):
-            if (self.__tab_panel.is_visible()):
-                self.__tab_panel.up()
-            else:
-                self.emit_event(msgs.HWKEY_EV_UP)
+            self.emit_event(msgs.HWKEY_EV_UP)
         elif (key == "Down"):
-            if (self.__tab_panel.is_visible()):
-                self.__tab_panel.down()
-            else:
-                self.emit_event(msgs.HWKEY_EV_DOWN)
+            self.emit_event(msgs.HWKEY_EV_DOWN)
         elif (key == "Left"):
-            if (self.__tab_panel.is_visible()):
-                self.__tab_panel.left()
-            else:
-                self.emit_event(msgs.HWKEY_EV_LEFT)
+            self.emit_event(msgs.HWKEY_EV_LEFT)
         elif (key == "Right"):
-            if (self.__tab_panel.is_visible()):
-                self.__tab_panel.right()
-            else:
-                self.emit_event(msgs.HWKEY_EV_RIGHT)
+             self.emit_event(msgs.HWKEY_EV_RIGHT)
 
             
         elif (key == "XF86Headset"):
@@ -627,35 +520,8 @@ class AppWindow(Component, RootPane):
         """
         Displays the virtual keyboard.
         """
-
-        #def f(src, cmd, *args):            
-        #    if (cmd == src.OBS_DELETE):
-        #        term = self.__get_search_term()
-        #        term = term[:-1]
-        #        self.__set_search_term(term)
-        #    
-        #    elif (cmd == src.OBS_KEY):
-        #        key = args[0]
-        #        
-        #        term = self.__get_search_term()
-        #        term += key.lower()
-        #        self.__set_search_term(term)
-
-
-        #w, h = self.get_size()
-    
-        #osim = OnScreenInputMethod()
-        #osim.add_observer(f)
-        #osim.popup(self.__window)
-        
+       
         self.emit_event(msgs.VKB_ACT_SHOW, self.__window)
-        
-        #try:
-        #    hildon_input_method.show_im(self.__window, f)
-        #except:
-        #    # only available on maemo
-        #    pass
-        #self.__set_search_term("")
 
 
 
@@ -697,39 +563,6 @@ class AppWindow(Component, RootPane):
         if (term):
             self.emit_event(msgs.CORE_ACT_SEARCH_ITEM, term)
             
-        
-
-    def __on_observe_window_ctrls(self, src, cmd, *args):
-    
-        if (cmd == src.OBS_MINIMIZE_WINDOW):
-            self.__window.iconify()
-
-        elif (cmd == src.OBS_MAXIMIZE_WINDOW):
-            #self.set_frozen(False)
-            self.__is_fullscreen = not self.__is_fullscreen
-            if (self.__is_fullscreen): self.__window.fullscreen()
-            else: self.__window.unfullscreen()
-
-        elif (cmd == src.OBS_CLOSE_WINDOW):
-            self.__try_quit()
-
-
-    def __on_observe_tabs(self, src, cmd, *args):
-    
-        if (cmd == src.OBS_TAB_SELECTED):
-            idx = args[0]
-            self.__select_tab(idx)
-        
-        elif (cmd == src.OBS_REPEAT_MODE):
-            mode = args[0]
-            config.set_repeat_mode(mode)
-            self.__prepare_collection_caps()
-            
-        elif (cmd == src.OBS_SHUFFLE_MODE):
-            mode = args[0]
-            config.set_shuffle_mode(mode)
-            self.__prepare_collection_caps()
-
 
     def __on_observe_strip(self, src, cmd, *args):
     
@@ -748,7 +581,7 @@ class AppWindow(Component, RootPane):
                 self.__select_item(idx)
                 handled = True
             elif (0 <= px <= 80 and py >= h - 60):
-                self.__show_tabs()
+                self.emit_message(msgs.INPUT_EV_MENU)
                 handled = True
 
         return handled        
@@ -760,6 +593,8 @@ class AppWindow(Component, RootPane):
             component = args[0]
             if (isinstance(component, Viewer)):
                 self.__viewers.append(component)
+            elif (isinstance(component, Widget)):
+                self.add(component)
     
         elif (event == msgs.COM_EV_LOADING_MODULE):
             name = args[0]
@@ -768,23 +603,28 @@ class AppWindow(Component, RootPane):
                               theme.mb_viewer_audio)
             
     
+        elif (event == msgs.CORE_ACT_APP_MINIMIZE):
+            self.__window.iconify()
+            
+        elif (event == msgs.CORE_ACT_APP_CLOSE):
+            self.__try_quit()
+
         elif (event == msgs.CORE_ACT_SCAN_MEDIA):
             force_rebuild = args[0]
             self.__scan_media(force_rebuild)
    
+        elif (event == msgs.MEDIASCANNER_EV_SCANNING_STARTED):
+            self.show_overlay("Scanning Media", "", theme.mb_viewer_audio)
+
         elif (event == msgs.MEDIASCANNER_EV_SCANNING_PROGRESS):
             name = args[0]
             self.show_overlay("Scanning Media", "- %s -" % name,
                               theme.mb_viewer_audio)
-   
-        #elif (event == msgs.CORE_EV_DEVICE_ADDED):
-        #    ident, dev = args
-        #    gobject.timeout_add(0, self.__scan_media, True)
-        
-        #elif (event == msgs.CORE_ACT_SHOW_MENU):
-        #    self.__show_tabs()
-        #    self.drop_event()
-        
+
+        elif (event == msgs.MEDIASCANNER_EV_SCANNING_FINISHED):
+            self.hide_overlay()
+
+
         elif (event == msgs.CORE_EV_THEME_CHANGED):
             from mediabox import thumbnail
             thumbnail.clear_cache()
@@ -804,6 +644,7 @@ class AppWindow(Component, RootPane):
             
         elif (event == msgs.UI_ACT_THAW):
             self.set_frozen(False)
+            self.__prepare_collection_caps()
             self.render_buffered()
             
         elif (event == msgs.UI_ACT_RENDER):
@@ -825,6 +666,10 @@ class AppWindow(Component, RootPane):
             vstate.item_offset = 0
             if (viewer == self.__current_viewer):
                 self.__set_collection(items)
+                
+        elif (event == msgs.UI_ACT_CHANGE_STRIP):
+            owner = args[0]
+            self.__strip.change_image_set(owner)
                
         elif (event == msgs.UI_ACT_HILIGHT_STRIP_ITEM):
             viewer, idx = args
@@ -895,23 +740,7 @@ class AppWindow(Component, RootPane):
         elif (event == msgs.MEDIA_EV_VOLUME_CHANGED):
             percent = args[0]
             self.__title_panel.set_volume(percent)
-            
-        elif (event == msgs.MEDIA_EV_LOADED):
-            viewer, f = args
-            idx = self.__viewers.index(viewer)
-            self.__tab_panel.set_currently_playing(idx)
 
-
-        elif (event == msgs.INPUT_EV_MENU):
-            if (self.__tab_panel.is_visible()):
-                self.__tab_panel.select_current()
-            else:
-                self.__show_tabs()
-
-        elif (event == msgs.INPUT_EV_ENTER):
-            if (self.__tab_panel.is_visible()):
-                self.__tab_panel.select_current()
-                
         elif (event == msgs.HWKEY_EV_BACKSPACE):
             term = self.__get_search_term()
             if (term):
@@ -923,6 +752,17 @@ class AppWindow(Component, RootPane):
             term = self.__get_search_term()
             term += key.lower()
             self.__set_search_term(term)
+            
+        elif (event == msgs.INPUT_EV_PREVIOUS_VIEWER):
+            idx = self.__viewers.index(self.__current_viewer)
+            if (idx > 0):
+                self.__select_viewer(idx - 1)
+                
+        elif (event == msgs.INPUT_EV_NEXT_VIEWER):
+            idx = self.__viewers.index(self.__current_viewer)
+            if (idx < len(self.__viewers) - 1):
+                self.__select_viewer(idx + 1)
+
 
 
 
@@ -944,9 +784,6 @@ class AppWindow(Component, RootPane):
         self.__hilight_item(idx)
 
         if (not hilight_only):
-            #item = self.__current_collection[idx]
-            #self.__get_vstate().selected_item = idx
-            #self.__current_viewer.load(item)
             self.emit_event(msgs.CORE_ACT_LOAD_ITEM, idx)
             
         self.__strip.scroll_to_item(idx)
@@ -965,10 +802,8 @@ class AppWindow(Component, RootPane):
         viewers = [ v for v in self.__viewers if repr(v) == name ]
         if (viewers):
             idx = self.__viewers.index(viewers[0])
-            self.__tab_panel.select_viewer(idx)
             self.__select_viewer(idx)
         else:
-            self.__tab_panel.select_viewer(0)
             self.__select_viewer(0)
             
 
@@ -996,15 +831,13 @@ class AppWindow(Component, RootPane):
         self.set_frozen(True)
         viewer.show()
         
-        self.__current_viewer.show()
-        self.__set_collection(vstate.items)
+        #self.__set_collection(vstate.items)
         self.__strip.set_offset(vstate.item_offset)
         if (vstate.selected_item >= 0):
             self.__hilight_item(vstate.selected_item)
         
         self.set_frozen(False)
         self.fx_slide_in() #render() #_buffered()
-        self.__tab_panel.close()
         #self.render()
         self.emit_event(msgs.INPUT_ACT_REPORT_CONTEXT)
         self.emit_event(msgs.UI_EV_VIEWER_CHANGED, idx)
