@@ -38,7 +38,7 @@ class AudioAlbumStorage(AudioArtistStorage):
         
     def get_name(self):
     
-        return "By Album"
+        return "Albums"
 
 
     def get_icon(self):
@@ -56,6 +56,7 @@ class AudioAlbumStorage(AudioArtistStorage):
         f.mimetype = f.DIRECTORY
         f.resource = ""
         f.name = self.get_name()
+        f.info = "Browse your music library by album"
         
         return f
           
@@ -63,57 +64,46 @@ class AudioAlbumStorage(AudioArtistStorage):
     
     def ls_async(self, path, cb, *args):
 
-        if (not path.endswith("/")): path += "/"        
-        num_of_slash = len(path) - len(path.replace("/", ""))
+        if (not path.endswith("/")): path += "/"
+        parts = [ p for p in path.split("/") if p ]
+        len_parts = len(parts)
+        index = self.get_index()
         
-        if (num_of_slash == 1):
-            seen = []
-            artists = self._list_artists()
-            artists.sort()
-            for artist in artists:
-                albums = self._list_albums(artist)
-                albums.sort()
+        if (len_parts == 0):
+            for album in index.list_albums():
+                #children = index.list_files(album)
+                #if (children):
+                #    f = self.call_service(msgs.CORE_SVC_GET_FILE, children[0])
+                #    tags = tagreader.get_tags(f)
+                #    artist = tags.get("ARTIST") or "unknown"
+                #else:
+                #    artist = "unknown"
             
-                for album, fp in albums:
-                    if (album in seen): continue
-                    
-                    seen.append(album)
-                    album_f = self.call_service(msgs.CORE_SVC_GET_FILE, fp)
-                    f = File(self)
-                    f.is_local = True
-                    f.path = path + urlquote.quote(artist + "/" + album)
-                    f.can_skip = True
-                    f.name = album
-                    f.info = artist
-                    #f.info = "%d items" % len(self.__albums[(artist, album)])
-                    f.mimetype = "application/x-music-folder" #f.DIRECTORY
-                    if (album_f):
-                        f.resource = album_f.resource
-                        f.thumbnail_md5 = album_f.md5
+                f = File(self)
+                f.is_local = True
+                f.path = path + urlquote.quote(album, "")
+                f.can_skip = True
+                f.name = album
+                #f.info = artist
+                f.mimetype = "application/x-music-folder"
+
+                cb(f, *args)
+            #end for
 
-                    cb(f, *args)
-                #end for
-            #end for            
             cb(None, *args)
             
         else:
-            parts = path.split("/")
-            artist = urlquote.unquote(parts[1])
-            album = urlquote.unquote(parts[2])
-
+            album = urlquote.unquote(parts[0])
             tracks = []
             
-            for f in self._list_files(artist, album):
+            for filepath in index.list_files(album):
+                f = self.call_service(msgs.CORE_SVC_GET_FILE, filepath)
+                
                 tags = tagreader.get_tags(f)
                 f.name = tags.get("TITLE") or f.name
                 f.info = tags.get("ARTIST") or "unknown"
                 al = tags.get("ALBUM")
-                
-                if (album != al
-                    and album != os.path.basename(os.path.dirname(f.resource))):
-                    continue
-                #if ((artist, album) != (f.info, al)): continue
-                
+
                 try:
                     trackno = tags.get("TRACKNUMBER")
                     trackno = trackno.split("/")[0]
