@@ -46,6 +46,13 @@ class MPlayerBackend(AbstractBackend):
         return theme.mb_backend_mplayer
 
 
+    def __busy_wait(self, delay):
+    
+        next = time.time() + delay
+        while (time.time() < next):
+            pass
+
+
     def __start_mplayer(self):
     
         if (self._get_mode() == self.MODE_AUDIO):
@@ -59,7 +66,7 @@ class MPlayerBackend(AbstractBackend):
             product = maemo.get_product_code()
             if (product == "?"):
                 logging.debug("mplayer backend detected non-maemo device")
-                vo_opts = "-vo xv"
+                vo_opts = "-vo xv -softsleep"
             elif (product == "SU-18"):
                 logging.debug("mplayer backend detected Nokia 770")
                 vo_opts = "-vo nokia770"
@@ -67,11 +74,13 @@ class MPlayerBackend(AbstractBackend):
                                           #"x=174:y=60:w=600:h=360")
             else:
                 logging.debug("mplayer backend detected Nokia maemo-device")
-                vo_opts = "-vo xv"
+                vo_opts = "-vo xv:ck-method=auto "\
+                          "-noslices -framedrop " \
+                          "-lavdopts fast:lowres=1,480"
         
             cmd = "LANG=C %s -quiet -slave " \
                   "-noconsolecontrols -nojoystick -nolirc -nomouseinput " \
-                  "-idle -osdlevel 0 -idx " \
+                  "-nomenu -idle -osdlevel 0 -idx " \
                   "-cache 256 -cache-min 50 " \
                   "-identify -wid %d %s 2>&1 3>/dev/null" \
                   % (_MPLAYER, self.__window_id, vo_opts)
@@ -83,7 +92,10 @@ class MPlayerBackend(AbstractBackend):
                              stdin=subprocess.PIPE, stdout=subprocess.PIPE,
                              close_fds=True)
 
-        time.sleep(0.25)
+        # a busy wait puts load on the CPU and this seems to help when
+        # starting mplayer on maemo to get smoother playback
+        self.__busy_wait(0.25)
+        
         if (p.poll()):
             print "Startup failed"
             self._report_error(self.ERR_INVALID, "Could not start mplayer")
@@ -145,7 +157,7 @@ class MPlayerBackend(AbstractBackend):
 
     def __read(self):
                 
-        data = self.__stdout.read(1024)
+        data = self.__stdout.read(4096)
         logging.debug("mplayer output:\n%s" % data)
         return data
 
@@ -182,6 +194,9 @@ class MPlayerBackend(AbstractBackend):
     
         if (xid != self.__window_id):
             self.__window_id = xid
+        # restart required
+        if (self.__stdin):
+            self.__stop_mplayer()
         
         
     def _is_eof(self):
@@ -210,6 +225,7 @@ class MPlayerBackend(AbstractBackend):
         
         uri = uri.replace("\"", "\\\"")
         self.__send_cmd("loadfile \"%s\"" % uri)
+        self.__busy_wait(0.25)
         self.__send_cmd("get_time_length")
         self.__send_cmd("get_time_pos")
         
@@ -308,7 +324,8 @@ class MPlayerBackend(AbstractBackend):
                                     self.__media_length
 
         elif (data.startswith("ANS_LENGTH")):
-            self.__media_length = float(self.__read_ans(data))
+            if (self.__media_length == 0):
+                self.__media_length = float(self.__read_ans(data))
 
         elif (data.startswith("ANS_VIDEO_RESOLUTION")):
             res = self.__read_ans(data)
@@ -405,6 +422,10 @@ class MPlayerBackend(AbstractBackend):
         elif (data.startswith("Error opening/initializing ")):
             #print "ERROR OPENING"
             self._report_error(self.ERR_INVALID, "")
+            
+        elif (data.startswith("- MPlayer crashed.")):
+            self._report_error(self.ERR_INVALID, "")
+            self.__stop_mplayer()
 
         elif (data.startswith("Server returned 400:Server Full")):
             #print "ERROR 400:Server Full"
